ProSHADE: src/proshade/ProSHADE_messages.hpp Source File

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_messages.hpp
Go to the documentation of this file.
1
22 //============================================ ProSHADE
23 #include "ProSHADE_exceptions.hpp"
24
25 //============================================ Overinclusion protection
26 #ifndef __PROSHADE_MESSAGES__
27 #define __PROSHADE_MESSAGES__
28
29 //============================================ ProSHADE_internal_messages Namespace
36 namespace ProSHADE_internal_messages
37 {
38 void printWellcomeMessage ( proshade_signed verbose );
39 void printTerminateMessage ( proshade_signed verbose );
40 void printProgressMessage ( proshade_signed verbose, proshade_signed messageLevel, std::string message );
41 void printWarningMessage ( proshade_signed verbose, std::string message, std::string warnCode );
42 void printHelp ( void );
43 }
44
45 #endif
ProSHADE_exceptions.hpp
This header file contains the ProSHADE_exception class, which is used to report errors occuring durin...
ProSHADE_internal_messages::printWarningMessage
void printWarningMessage(proshade_signed verbose, std::string message, std::string warnCode)
General stderr message printing (used for warnings).
Definition: ProSHADE_messages.cpp:101
ProSHADE_internal_messages::printWellcomeMessage
void printWellcomeMessage(proshade_signed verbose)
Wellcome message printing.
Definition: ProSHADE_messages.cpp:31
ProSHADE_internal_messages::printTerminateMessage
void printTerminateMessage(proshade_signed verbose)
Final message printing.
Definition: ProSHADE_messages.cpp:49
ProSHADE_internal_messages
This namespace contains all the functions used for reporting back to the user.
ProSHADE_internal_messages::printProgressMessage
void printProgressMessage(proshade_signed verbose, proshade_signed messageLevel, std::string message)
General stdout message printing.
Definition: ProSHADE_messages.cpp:70
ProSHADE_internal_messages::printHelp
void printHelp(void)
This function prints the help screen in the case -h is called, or if command line arguments cannot be...
Definition: ProSHADE_messages.cpp:118